##  Setting Up the Integration
To learn how to set up the integration, see [Setting Up the GitHub Enterprise Integration](https://help.sap.com/docs/leanix/ea/setting-up-github-enterprise-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step instructions for setting up the GitHub Enterprise Server integration.").
